@@ -1,4 +1,7 @@
 package CatalystX::Component::Traits;
+{
+  $CatalystX::Component::Traits::VERSION = '0.18';
+}
 
 use namespace::autoclean;
 use Moose::Role;
@@ -6,7 +9,6 @@ use Carp;
 use List::MoreUtils qw/firstidx any uniq/;
 use Scalar::Util 'reftype';
 use Class::Load qw/ load_first_existing_class /;
-
 with 'MooseX::Traits::Pluggable' => { -excludes => ['_find_trait'] };
 
 =head1 NAME
@@ -14,13 +16,8 @@ with 'MooseX::Traits::Pluggable' => { -excludes => ['_find_trait'] };
 CatalystX::Component::Traits - Automatic Trait Loading and Resolution for
 Catalyst Components
 
-=head1 VERSION
-
-Version 0.17
-
 =cut
 
-our $VERSION   = '0.17';
 our $AUTHORITY = 'id:RKITOVER';
 
 =head1 SYNOPSIS
@@ -255,41 +252,17 @@ L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CatalystX-Component-Traits>.  I
 will be notified, and then you'll automatically be notified of progress on your
 bug as I make changes.
 
-=head1 SUPPORT
-
-More information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=CatalystX-Component-Traits>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/CatalystX-Component-Traits>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/CatalystX-Component-Traits>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/CatalystX-Component-Traits/>
-
-=back
-
 =head1 ACKNOWLEDGEMENTS
 
 Matt S. Trout and Tomas Doran helped me with the current design.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2009, Rafael Kitover
+Copyright (c) 2014, Rafael Kitover
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
 
-1; # End of CatalystX::Component::Traits
+__PACKAGE__; # End of CatalystX::Component::Traits
